@@ -3,7 +3,7 @@ Author: WildboarG
 version: 1.0
 Date: 2022-05-27 15:23:10
 LastEditors: WildboarG
-LastEditTime: 2022-08-24 22:32:02
+LastEditTime: 2022-08-30 23:03:09
 Descripttion: 
 '''
 
@@ -13,7 +13,7 @@ import json
 import time
 
 schoolcode="zit"
-authorityid=["10025","10081","10214","10263"]
+authorityid=["10025","10214","10263"]
 activityid ="2614"
 
 index = "https://api.{}.edu.cn".format(schoolcode)      # 获取cook的host
